.. image:: https://travis-ci.org/zopefoundation/Products.ZSQLMethods.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/Products.ZSQLMethods

.. image:: https://coveralls.io/repos/github/zopefoundation/Products.ZSQLMethods/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/Products.ZSQLMethods?branch=master

.. image:: https://img.shields.io/pypi/v/Products.ZSQLMethods.svg
        :target: https://pypi.org/project/Products.ZSQLMethods/
        :alt: Current version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Products.ZSQLMethods.svg
        :target: https://pypi.org/project/Products.ZSQLMethods/
        :alt: Supported Python versions

Products.ZSQLMethods
====================

This Zope product provides support for SQL Method objects in
Zope. They can be used in conjunction with any database adapter to use
relational database data from within the Zope environment.
